@@ -22,9 +22,9 @@ import discord
 # Set the event loop policies here so any subsequent `new_event_loop()`
 # calls, in particular those as a result of the following imports,
 # return the correct loop object.
-from redbot import _update_event_loop_policy, __version__
+from redbot import _early_init, __version__
 
-_update_event_loop_policy()
+_early_init()
 
 import redbot.logging
 from redbot.core.bot import Red, ExitCodes
@@ -446,13 +446,18 @@ def global_exception_handler(red, loop, context):
     """
     Logs unhandled exceptions in other tasks
     """
-    msg = context.get("exception", context["message"])
+    exc = context.get("exception")
     # These will get handled later when it *also* kills loop.run_forever
-    if not isinstance(msg, (KeyboardInterrupt, SystemExit)):
-        if isinstance(msg, Exception):
-            log.critical("Caught unhandled exception in task:\n", exc_info=msg)
-        else:
-            log.critical("Caught unhandled exception in task: %s", msg)
+    if exc is not None and isinstance(exc, (KeyboardInterrupt, SystemExit)):
+        return
+    # Maybe in the future we should handle some of the other things
+    # that the default exception handler handles, but this should work fine for now.
+    log.critical(
+        "Caught unhandled exception in %s:\n%s",
+        context.get("future", "event loop"),
+        context["message"],
+        exc_info=exc,
+    )
 
 
 def red_exception_handler(red, red_task: asyncio.Future):
