@@ -149,7 +149,7 @@ class AudioAPIInterface:
         async with self._lock:
             if lock_id in self._tasks:
                 if IS_DEBUG:
-                    log.debug(f"Running database writes for {lock_id} ({lock_author})")
+                    log.debug("Running database writes for %d (%s)", lock_id, lock_author)
                 try:
                     tasks = self._tasks[lock_id]
                     tasks = [self.route_tasks(a, tasks[a]) for a in tasks]
@@ -157,11 +157,11 @@ class AudioAPIInterface:
                     del self._tasks[lock_id]
                 except Exception as exc:
                     debug_exc_log(
-                        log, exc, f"Failed database writes for {lock_id} ({lock_author})"
+                        log, exc, "Failed database writes for %d (%s)", lock_id, lock_author
                     )
                 else:
                     if IS_DEBUG:
-                        log.debug(f"Completed database writes for {lock_id} ({lock_author})")
+                        log.debug("Completed database writes for %d (%s)", lock_id, lock_author)
 
     async def run_all_pending_tasks(self) -> None:
         """Run all pending tasks left in the cache, called on cog_unload."""
@@ -248,7 +248,9 @@ class AudioAPIInterface:
                             {"track": track_info}
                         )
                     except Exception as exc:
-                        debug_exc_log(log, exc, f"Failed to fetch {track_info} from YouTube table")
+                        debug_exc_log(
+                            log, exc, "Failed to fetch %r from YouTube table", track_info
+                        )
 
                 if val is None:
                     try:
@@ -386,7 +388,7 @@ class AudioAPIInterface:
                 )
             except Exception as exc:
                 debug_exc_log(
-                    log, exc, f"Failed to fetch 'spotify:track:{uri}' from Spotify table"
+                    log, exc, "Failed to fetch 'spotify:track:%s' from Spotify table", uri
                 )
                 val = None
         else:
@@ -513,7 +515,9 @@ class AudioAPIInterface:
                             {"track": track_info}
                         )
                     except Exception as exc:
-                        debug_exc_log(log, exc, f"Failed to fetch {track_info} from YouTube table")
+                        debug_exc_log(
+                            log, exc, "Failed to fetch %r from YouTube table", track_info
+                        )
                 should_query_global = globaldb_toggle and query_global and val is None
                 if should_query_global:
                     llresponse = await self.global_cache_api.get_spotify(track_name, artist_name)
@@ -621,7 +625,7 @@ class AudioAPIInterface:
                 ):
                     has_not_allowed = True
                     if IS_DEBUG:
-                        log.debug(f"Query is not allowed in {ctx.guild} ({ctx.guild.id})")
+                        log.debug("Query is not allowed in %r (%d)", ctx.guild.name, ctx.guild.id)
                     continue
                 track_list.append(single_track)
                 if enqueue:
@@ -640,7 +644,7 @@ class AudioAPIInterface:
                             player.add(ctx.author, single_track)
                             self.bot.dispatch(
                                 "red_audio_track_enqueue",
-                                player.channel.guild,
+                                player.guild,
                                 single_track,
                                 ctx.author,
                             )
@@ -656,7 +660,7 @@ class AudioAPIInterface:
                         player.add(ctx.author, single_track)
                         self.bot.dispatch(
                             "red_audio_track_enqueue",
-                            player.channel.guild,
+                            player.guild,
                             single_track,
                             ctx.author,
                         )
@@ -748,7 +752,7 @@ class AudioAPIInterface:
             try:
                 (val, update) = await self.local_cache_api.youtube.fetch_one({"track": track_info})
             except Exception as exc:
-                debug_exc_log(log, exc, f"Failed to fetch {track_info} from YouTube table")
+                debug_exc_log(log, exc, "Failed to fetch %r from YouTube table", track_info)
         if val is None:
             try:
                 youtube_url = await self.fetch_youtube_query(
@@ -813,11 +817,11 @@ class AudioAPIInterface:
                     {"query": query_string}
                 )
             except Exception as exc:
-                debug_exc_log(log, exc, f"Failed to fetch '{query_string}' from Lavalink table")
+                debug_exc_log(log, exc, "Failed to fetch %r from Lavalink table", query_string)
 
             if val and isinstance(val, dict):
                 if IS_DEBUG:
-                    log.debug(f"Updating Local Database with {query_string}")
+                    log.debug("Updating Local Database with %r", query_string)
                 task = ("update", ("lavalink", {"query": query_string}))
                 self.append_task(ctx, *task)
             else:
@@ -851,7 +855,7 @@ class AudioAPIInterface:
                     valid_global_entry = True
                 if valid_global_entry:
                     if IS_DEBUG:
-                        log.debug(f"Querying Global DB api for {query}")
+                        log.debug("Querying Global DB api for %r", query)
                     results, called_api = results, False
         if valid_global_entry:
             pass
@@ -870,7 +874,7 @@ class AudioAPIInterface:
             valid_global_entry = False
         else:
             if IS_DEBUG:
-                log.debug(f"Querying Lavalink api for {query_string}")
+                log.debug("Querying Lavalink api for %r", query_string)
             called_api = True
             try:
                 results = await player.load_tracks(query_string)
@@ -923,16 +927,17 @@ class AudioAPIInterface:
                 debug_exc_log(
                     log,
                     exc,
-                    f"Failed to enqueue write task for '{query_string}' to Lavalink table",
+                    "Failed to enqueue write task for %r to Lavalink table",
+                    query_string,
                 )
         return results, called_api
 
     async def autoplay(self, player: lavalink.Player, playlist_api: PlaylistWrapper):
         """Enqueue a random track."""
-        autoplaylist = await self.config.guild(player.channel.guild).autoplaylist()
+        autoplaylist = await self.config.guild(player.guild).autoplaylist()
         current_cache_level = CacheLevel(await self.config.cache_level())
         cache_enabled = CacheLevel.set_lavalink().is_subset(current_cache_level)
-        notify_channel_id = player.fetch("channel")
+        notify_channel_id = player.fetch("notify_channel")
         playlist = None
         tracks = None
         if autoplaylist["enabled"]:
@@ -942,8 +947,8 @@ class AudioAPIInterface:
                     autoplaylist["scope"],
                     self.bot,
                     playlist_api,
-                    player.channel.guild,
-                    player.channel.guild.me,
+                    player.guild,
+                    player.guild.me,
                 )
                 tracks = playlist.tracks_obj
             except Exception as exc:
@@ -956,9 +961,7 @@ class AudioAPIInterface:
             if not tracks:
                 ctx = namedtuple("Context", "message guild cog")
                 (results, called_api) = await self.fetch_track(
-                    cast(
-                        commands.Context, ctx(player.channel.guild, player.channel.guild, self.cog)
-                    ),
+                    cast(commands.Context, ctx(player.guild, player.guild, self.cog)),
                     player,
                     Query.process_input(_TOP_100_US, self.cog.local_folder_current_path),
                 )
@@ -990,8 +993,7 @@ class AudioAPIInterface:
                 ):
                     if IS_DEBUG:
                         log.debug(
-                            "Query is not allowed in "
-                            f"{player.channel.guild} ({player.channel.guild.id})"
+                            "Query is not allowed in %r (%d)", player.guild.name, player.guild.id
                         )
                     continue
                 valid = True
@@ -1000,24 +1002,24 @@ class AudioAPIInterface:
                     "autoplay": True,
                     "enqueue_time": int(time.time()),
                     "vc": player.channel.id,
-                    "requester": player.channel.guild.me.id,
+                    "requester": player.guild.me.id,
                 }
             )
-            player.add(player.channel.guild.me, track)
+            player.add(player.guild.me, track)
             self.bot.dispatch(
                 "red_audio_track_auto_play",
-                player.channel.guild,
+                player.guild,
                 track,
-                player.channel.guild.me,
+                player.guild.me,
                 player,
             )
             if notify_channel_id:
                 await self.config.guild_from_id(
-                    guild_id=player.channel.guild.id
+                    guild_id=player.guild.id
                 ).currently_auto_playing_in.set([notify_channel_id, player.channel.id])
             else:
                 await self.config.guild_from_id(
-                    guild_id=player.channel.guild.id
+                    guild_id=player.guild.id
                 ).currently_auto_playing_in.set([])
             if not player.current:
                 await player.play()
