@@ -583,22 +583,29 @@ class Downloader(commands.Cog):
             if repo.install_msg:
                 await ctx.send(repo.install_msg.replace("[p]", ctx.clean_prefix))
 
-    @repo.command(name="delete", aliases=["remove", "del"])
-    async def _repo_del(self, ctx: commands.Context, repo: Repo) -> None:
+    @repo.command(name="delete", aliases=["remove", "del"], require_var_positional=True)
+    async def _repo_del(self, ctx: commands.Context, *repos: Repo) -> None:
         """
-        Remove a repo and its files.
+        Remove repos and their files.
 
-        Example:
+        Examples:
             - `[p]repo delete 26-Cogs`
+            - `[p]repo delete 26-Cogs Laggrons-Dumb-Cogs`
 
         **Arguments**
 
-        - `<repo>` The name of an already added repo
+        - `<repos...>` The repo or repos to remove.
         """
-        await self._repo_manager.delete_repo(repo.name)
+        for repo in set(repos):
+            await self._repo_manager.delete_repo(repo.name)
 
         await ctx.send(
-            _("The repo `{repo.name}` has been deleted successfully.").format(repo=repo)
+            (
+                _("Successfully deleted repos: ")
+                if len(repos) > 1
+                else _("Successfully deleted the repo: ")
+            )
+            + humanize_list([inline(i.name) for i in set(repos)])
         )
 
     @repo.command(name="list")
@@ -825,7 +832,7 @@ class Downloader(commands.Cog):
                     message += (
                         _("\nFailed to install requirements: ")
                         if len(failed_reqs) > 1
-                        else _("\nFailed to install requirement: ")
+                        else _("\nFailed to install the requirement: ")
                     ) + humanize_list(tuple(map(inline, failed_reqs)))
                     await self.send_pagified(ctx, message)
                     return
@@ -870,7 +877,7 @@ class Downloader(commands.Cog):
                     (
                         _("Successfully installed cogs: ")
                         if len(installed_cogs) > 1
-                        else _("Successfully installed the cog:")
+                        else _("Successfully installed the cog: ")
                     )
                     + humanize_list(cognames)
                     + (
@@ -904,8 +911,8 @@ class Downloader(commands.Cog):
         by Downloader.
 
         Examples:
-            - `[p]cog uninstall 26-Cogs defender`
-            - `[p]cog uninstall Laggrons-Dumb-Cogs say roleinvite`
+            - `[p]cog uninstall defender`
+            - `[p]cog uninstall say roleinvite`
 
         **Arguments**
 
@@ -1423,7 +1430,7 @@ class Downloader(commands.Cog):
                 _("\nCouldn't find these cogs in {repo.name}: ")
                 if len(unavailable_cogs) > 1
                 else _("\nCouldn't find this cog in {repo.name}: ")
-            ) + humanize_list(unavailable_cogs)
+            ).format(repo=repo) + humanize_list(unavailable_cogs)
         if already_installed:
             message += (
                 _("\nThese cogs were already installed: ")
@@ -1434,7 +1441,7 @@ class Downloader(commands.Cog):
             message += (
                 _("\nSome cogs with these names are already installed from different repos: ")
                 if len(name_already_used) > 1
-                else _("Cog with this is already installed from a different repo.")
+                else _("Cog with this name is already installed from a different repo.")
             ) + humanize_list(name_already_used)
         correct_cogs, add_to_message = self._filter_incorrect_cogs(cogs)
         if add_to_message:
