@@ -516,6 +516,9 @@ class Mutes(VoiceMutes, commands.Cog, metaclass=CompositeMetaClass):
         reason: Optional[str],
         duration=None,
     ):
+        if user.bot:
+            return
+
         if not await self.config.guild(guild).dm():
             return
 
@@ -780,12 +783,12 @@ class Mutes(VoiceMutes, commands.Cog, metaclass=CompositeMetaClass):
 
     @muteset.command(name="forcerole")
     @commands.is_owner()
-    async def force_role_mutes(self, ctx: commands.Context, force_role_mutes: bool):
+    async def force_role_mutes(self, ctx: commands.Context, true_or_false: bool):
         """
         Whether or not to force role only mutes on the bot
         """
-        await self.config.force_role_mutes.set(force_role_mutes)
-        if force_role_mutes:
+        await self.config.force_role_mutes.set(true_or_false)
+        if true_or_false:
             await ctx.send(_("Okay I will enforce role mutes before muting users."))
         else:
             await ctx.send(_("Okay I will allow channel overwrites for muting users."))
@@ -1710,6 +1713,12 @@ class Mutes(VoiceMutes, commands.Cog, metaclass=CompositeMetaClass):
                     "channel": channel,
                     "reason": _(MUTE_UNMUTE_ISSUES["left_guild"]),
                 }
+        except discord.Forbidden:
+            return {
+                "success": False,
+                "channel": channel,
+                "reason": _(MUTE_UNMUTE_ISSUES["permissions_issue_channel"]),
+            }
         if move_channel:
             try:
                 await user.move_to(channel)
