@@ -6,7 +6,6 @@ from redbot.core.utils._internal_utils import send_to_owners_with_prefix_replace
 from redbot.core.utils.chat_formatting import escape, pagify
 
 from .streamtypes import (
-    HitboxStream,
     PicartoStream,
     Stream,
     TwitchStream,
@@ -203,6 +202,7 @@ class Streams(commands.Cog):
             if self.ttv_bearer_cache["expires_at"] - datetime.now().timestamp() <= 60:
                 await self.get_twitch_bearer_token()
 
+    @commands.guild_only()
     @commands.command()
     async def twitchstream(self, ctx: commands.Context, channel_name: str):
         """Check if a Twitch channel is live."""
@@ -216,6 +216,7 @@ class Streams(commands.Cog):
         )
         await self.check_online(ctx, stream)
 
+    @commands.guild_only()
     @commands.command()
     @commands.cooldown(1, 30, commands.BucketType.guild)
     async def youtubestream(self, ctx: commands.Context, channel_id_or_name: str):
@@ -234,12 +235,7 @@ class Streams(commands.Cog):
             )
         await self.check_online(ctx, stream)
 
-    @commands.command()
-    async def smashcast(self, ctx: commands.Context, channel_name: str):
-        """Check if a smashcast channel is live."""
-        stream = HitboxStream(_bot=self.bot, name=channel_name)
-        await self.check_online(ctx, stream)
-
+    @commands.guild_only()
     @commands.command()
     async def picarto(self, ctx: commands.Context, channel_name: str):
         """Check if a Picarto channel is live."""
@@ -249,7 +245,7 @@ class Streams(commands.Cog):
     async def check_online(
         self,
         ctx: commands.Context,
-        stream: Union[PicartoStream, HitboxStream, YoutubeStream, TwitchStream],
+        stream: Union[PicartoStream, YoutubeStream, TwitchStream],
     ):
         try:
             info = await stream.is_online()
@@ -323,11 +319,6 @@ class Streams(commands.Cog):
         """Toggle alerts in this channel for a YouTube stream."""
         await self.stream_alert(ctx, YoutubeStream, channel_name_or_id)
 
-    @streamalert.command(name="smashcast")
-    async def smashcast_alert(self, ctx: commands.Context, channel_name: str):
-        """Toggle alerts in this channel for a Smashcast stream."""
-        await self.stream_alert(ctx, HitboxStream, channel_name)
-
     @streamalert.command(name="picarto")
     async def picarto_alert(self, ctx: commands.Context, channel_name: str):
         """Toggle alerts in this channel for a Picarto stream."""
@@ -537,9 +528,10 @@ class Streams(commands.Cog):
         """Set stream alert message when mentions are enabled.
 
         Use `{mention}` in the message to insert the selected mentions.
-        Use `{stream}` in the message to insert the channel or user name.
+        Use `{stream}` in the message to insert the channel or username.
+        Use `{stream.display_name}` in the message to insert the channel's display name (on Twitch, this may be different from `{stream}`).
 
-        For example: `[p]streamset message mention {mention}, {stream} is live!`
+        For example: `[p]streamset message mention {mention}, {stream.display_name} is live!`
         """
         guild = ctx.guild
         await self.config.guild(guild).live_message_mention.set(message)
@@ -550,9 +542,10 @@ class Streams(commands.Cog):
     async def without_mention(self, ctx: commands.Context, *, message: str):
         """Set stream alert message when mentions are disabled.
 
-        Use `{stream}` in the message to insert the channel or user name.
+        Use `{stream}` in the message to insert the channel or username.
+        Use `{stream.display_name}` in the message to insert the channel's display name (on Twitch, this may be different from `{stream}`).
 
-        For example: `[p]streamset message nomention {stream} is live!`
+        For example: `[p]streamset message nomention {stream.display_name} is live!`
         """
         guild = ctx.guild
         await self.config.guild(guild).live_message_nomention.set(message)
@@ -775,6 +768,13 @@ class Streams(commands.Cog):
 
                     stream.messages.clear()
                     await self.save_streams()
+                except APIError as e:
+                    log.error(
+                        "Something went wrong whilst trying to contact the stream service's API.\n"
+                        "Raw response data:\n%r",
+                        e,
+                    )
+                    continue
                 else:
                     if stream.messages:
                         continue
@@ -810,13 +810,18 @@ class Streams(commands.Cog):
                                 content = content.replace(
                                     "{stream.name}", str(stream.name)
                                 )  # Backwards compatibility
+                                content = content.replace(
+                                    "{stream.display_name}", str(stream.display_name)
+                                )
                                 content = content.replace("{stream}", str(stream.name))
                                 content = content.replace("{mention}", mention_str)
                             else:
-                                content = _("{mention}, {stream} is live!").format(
+                                content = _("{mention}, {display_name} is live!").format(
                                     mention=mention_str,
-                                    stream=escape(
-                                        str(stream.name), mass_mentions=True, formatting=True
+                                    display_name=escape(
+                                        str(stream.display_name),
+                                        mass_mentions=True,
+                                        formatting=True,
                                     ),
                                 )
                         else:
@@ -828,11 +833,16 @@ class Streams(commands.Cog):
                                 content = content.replace(
                                     "{stream.name}", str(stream.name)
                                 )  # Backwards compatibility
+                                content = content.replace(
+                                    "{stream.display_name}", str(stream.display_name)
+                                )
                                 content = content.replace("{stream}", str(stream.name))
                             else:
-                                content = _("{stream} is live!").format(
-                                    stream=escape(
-                                        str(stream.name), mass_mentions=True, formatting=True
+                                content = _("{display_name} is live!").format(
+                                    display_name=escape(
+                                        str(stream.display_name),
+                                        mass_mentions=True,
+                                        formatting=True,
                                     )
                                 )
                         await self._send_stream_alert(stream, channel, embed, content)
