@@ -126,6 +126,7 @@ class HelpSettings:
             "\nMaximum pages per guild (only used if menus are not used): {max_pages_in_guild}"
             "\nHelp is a menu: {use_menus}"
             "\nHelp shows hidden commands: {show_hidden}"
+            "\nHelp shows commands aliases: {show_aliases}"
             "\nHelp only shows commands which can be used: {verify_checks}"
             "\nHelp shows unusable commands when asked directly: {verify_exists}"
             "\nDelete delay: {delete_delay}"
@@ -379,7 +380,7 @@ class RedHelpFormatter(HelpFormatterABC):
                 def shorten_line(a_line: str) -> str:
                     if len(a_line) < 70:  # embed max width needs to be lower
                         return a_line
-                    return a_line[:67] + "..."
+                    return a_line[:67].rstrip() + "..."
 
                 subtext = "\n".join(
                     shorten_line(f"**{name}** {command.format_shortdoc_for_context(ctx)}")
@@ -409,7 +410,7 @@ class RedHelpFormatter(HelpFormatterABC):
                         width_gap = discord.utils._string_width(nm) - len(nm)
                         doc = com.format_shortdoc_for_context(ctx)
                         if len(doc) > doc_max_width:
-                            doc = doc[: doc_max_width - 3] + "..."
+                            doc = doc[: doc_max_width - 3].rstrip() + "..."
                         yield nm, doc, max_width - width_gap
 
                 subtext = "\n".join(
@@ -554,7 +555,7 @@ class RedHelpFormatter(HelpFormatterABC):
                 def shorten_line(a_line: str) -> str:
                     if len(a_line) < 70:  # embed max width needs to be lower
                         return a_line
-                    return a_line[:67] + "..."
+                    return a_line[:67].rstrip() + "..."
 
                 command_text = "\n".join(
                     shorten_line(f"**{name}** {command.format_shortdoc_for_context(ctx)}")
@@ -583,7 +584,7 @@ class RedHelpFormatter(HelpFormatterABC):
                         width_gap = discord.utils._string_width(nm) - len(nm)
                         doc = com.format_shortdoc_for_context(ctx)
                         if len(doc) > doc_max_width:
-                            doc = doc[: doc_max_width - 3] + "..."
+                            doc = doc[: doc_max_width - 3].rstrip() + "..."
                         yield nm, doc, max_width - width_gap
 
                 subtext = "\n".join(
@@ -621,7 +622,7 @@ class RedHelpFormatter(HelpFormatterABC):
                 def shorten_line(a_line: str) -> str:
                     if len(a_line) < 70:  # embed max width needs to be lower
                         return a_line
-                    return a_line[:67] + "..."
+                    return a_line[:67].rstrip() + "..."
 
                 cog_text = "\n".join(
                     shorten_line(f"**{name}** {command.format_shortdoc_for_context(ctx)}")
@@ -654,7 +655,7 @@ class RedHelpFormatter(HelpFormatterABC):
                     width_gap = discord.utils._string_width(nm) - len(nm)
                     doc = com.format_shortdoc_for_context(ctx)
                     if len(doc) > doc_max_width:
-                        doc = doc[: doc_max_width - 3] + "..."
+                        doc = doc[: doc_max_width - 3].rstrip() + "..."
                     yield nm, doc, max_width - width_gap
 
             for cog_name, data in coms:
@@ -804,7 +805,11 @@ class RedHelpFormatter(HelpFormatterABC):
         # save on config calls
         channel_permissions = ctx.channel.permissions_for(ctx.me)
 
-        if not (channel_permissions.add_reactions and help_settings.use_menus):
+        if not (
+            channel_permissions.add_reactions
+            and channel_permissions.read_message_history
+            and help_settings.use_menus
+        ):
 
             max_pages_in_guild = help_settings.max_pages_in_guild
             use_DMs = len(pages) > max_pages_in_guild
